==> aliyun_python_sdk_mse-3.0.2-py2.py3-none-any.whl: aliyunsdkmse/request/v20190531/CreateAlarmRuleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data

class CreateAlarmRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'CreateAlarmRule')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_NValue(self): # Integer
		return self.get_query_params().get('NValue')

	def set_NValue(self, NValue):  # Integer
		self.add_query_param('NValue', NValue)
	def get_AlarmItem(self): # String
		return self.get_query_params().get('AlarmItem')

	def set_AlarmItem(self, AlarmItem):  # String
		self.add_query_param('AlarmItem', AlarmItem)
	def get_Operator(self): # String
		return self.get_query_params().get('Operator')

	def set_Operator(self, Operator):  # String
		self.add_query_param('Operator', Operator)
	def get_AlarmAliasName(self): # String
		return self.get_query_params().get('AlarmAliasName')

	def set_AlarmAliasName(self, AlarmAliasName):  # String
		self.add_query_param('AlarmAliasName', AlarmAliasName)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_ContactGroupIds(self): # String
		return self.get_query_params().get('ContactGroupIds')

	def set_ContactGroupIds(self, ContactGroupIds):  # String
		self.add_query_param('ContactGroupIds', ContactGroupIds)
	def get_AlertWay(self): # String
		return self.get_query_params().get('AlertWay')

	def set_AlertWay(self, AlertWay):  # String
		self.add_query_param('AlertWay', AlertWay)
	def get_Aggregates(self): # String
		return self.get_query_params().get('Aggregates')

	def set_Aggregates(self, Aggregates):  # String
		self.add_query_param('Aggregates', Aggregates)
	def get_Value(self): # Float
		return self.get_query_params().get('Value')

	def set_Value(self, Value):  # Float
		self.add_query_param('Value', Value)

==> aliyun_python_sdk_mse-3.0.4-py2.py3-none-any.whl: aliyunsdkmse/request/v20190531/CreateAlarmRuleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data

class CreateAlarmRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'CreateAlarmRule','mse')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_NValue(self): # Integer
		return self.get_query_params().get('NValue')

	def set_NValue(self, NValue):  # Integer
		self.add_query_param('NValue', NValue)
	def get_AlarmItem(self): # String
		return self.get_query_params().get('AlarmItem')

	def set_AlarmItem(self, AlarmItem):  # String
		self.add_query_param('AlarmItem', AlarmItem)
	def get_Operator(self): # String
		return self.get_query_params().get('Operator')

	def set_Operator(self, Operator):  # String
		self.add_query_param('Operator', Operator)
	def get_AlarmAliasName(self): # String
		return self.get_query_params().get('AlarmAliasName')

	def set_AlarmAliasName(self, AlarmAliasName):  # String
		self.add_query_param('AlarmAliasName', AlarmAliasName)
	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_ContactGroupIds(self): # String
		return self.get_query_params().get('ContactGroupIds')

	def set_ContactGroupIds(self, ContactGroupIds):  # String
		self.add_query_param('ContactGroupIds', ContactGroupIds)
	def get_AcceptLanguage(self): # String
		return self.get_query_params().get('AcceptLanguage')

	def set_AcceptLanguage(self, AcceptLanguage):  # String
		self.add_query_param('AcceptLanguage', AcceptLanguage)
	def get_AlertWay(self): # String
		return self.get_query_params().get('AlertWay')

	def set_AlertWay(self, AlertWay):  # String
		self.add_query_param('AlertWay', AlertWay)
	def get_Aggregates(self): # String
		return self.get_query_params().get('Aggregates')

	def set_Aggregates(self, Aggregates):  # String
		self.add_query_param('Aggregates', Aggregates)
	def get_Value(self): # Float
		return self.get_query_params().get('Value')

	def set_Value(self, Value):  # Float
		self.add_query_param('Value', Value)
